@@ -1,4 +1,4 @@
-/* FIGARO'S PASSWORD MANAGER (FPM)
+/* FIGARO'S PASSWORD MANAGER 2 (FPM2)
  * Copyright (C) 2000 John Conneely
  * Copyright (C) 2008,2009 Aleš Koval
  *
@@ -129,7 +129,7 @@ on_button_password_cancel_clicked      (GtkButton       *button,
 
 
 void
-on_gpw_toggled                         (GtkEditable     *editable,
+on_gpw_toggled                         (GtkSpinButton   *spinbutton,
                                         gpointer         user_data);
 
 void
@@ -556,3 +556,10 @@ on_launcher_menu_activate              (GtkMenuItem     *menuitem,
 void
 on_clone_item1_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+
+void
+on_clist_main_row_activated            (GtkTreeView     *treeview,
+                                        GtkTreePath     *path,
+                                        GtkTreeViewColumn *column,
+                                        gpointer         user_data);
+
