@@ -127,7 +127,7 @@ fpm_file_save(gchar* file_name, gboolean convert)
   fpm_data* data;
   fpm_launcher* launcher;
   FILE * file;
-  gchar* cmd;
+//  gchar* cmd;
   gchar* tmp;
   GList * list;
   gint i;
@@ -224,10 +224,11 @@ fpm_file_save(gchar* file_name, gboolean convert)
   file=fopen(file_name, "w");
   xmlDocDump(file, doc);
   fclose(file);
-  cmd = g_strdup_printf("chmod 0600 %s", file_name);
+//  chmod(file_name, S_IRUSR | S_IWUSR);
+/*  cmd = g_strdup_printf("chmod 0600 %s", file_name);
   fpm_execute_shell(cmd);
   g_free(cmd);
-
+*/
   dia_str = g_strdup_printf(_("Saved %d password(s)."), i);
   fpm_statusbar_push(dia_str);
 
@@ -250,7 +251,7 @@ fpm_file_export(gchar *file_name, gint export_launchers, gchar *export_category)
   fpm_data* data;
   fpm_launcher* launcher;
   FILE * file;
-  gchar* cmd;
+//  gchar* cmd;
   gchar* tmp;
   GList * list;
   gint i;
@@ -323,10 +324,10 @@ fpm_file_export(gchar *file_name, gint export_launchers, gchar *export_category)
   file=fopen(file_name, "w");
   xmlDocDump(file, doc);
   fclose(file);
-  cmd = g_strdup_printf("chmod 0600 %s", file_name);
+/*  cmd = g_strdup_printf("chmod 0600 %s", file_name);
   fpm_execute_shell(cmd);
   g_free(cmd);
-
+*/
   dia_str = g_strdup_printf(_("Exported clear XML passwords to %s."), file_name);
   fpm_statusbar_push(dia_str);
   g_free(dia_str);
@@ -340,8 +341,6 @@ passfile_load(gchar* file_name)
   fpm_data* data;
   fpm_launcher* launcher;
   gint i;
-  //GtkStatusbar *entry;
-//  gchar *dia_str;
   gchar *cipher_name;
 
   /* Start from scratch */
